searchData={"content_type":"text/markdown","items":[{"doc":"Opens XLSX workbooks and reads its worksheets.","ref":"XlsxReader.html","title":"XlsxReader","type":"module"},{"doc":"```elixir\n{:ok, package} = XlsxReader.open(\"test.xlsx\")\n\nXlsxReader.sheet_names(package)\n# [\"Sheet 1\", \"Sheet 2\", \"Sheet 3\"]\n\n{:ok, rows} = XlsxReader.sheet(package, \"Sheet 1\")\n# [\n#   [\"Date\", \"Temperature\"],\n#   [~D[2019-11-01], 8.4],\n#   [~D[2019-11-02], 7.5],\n#   ...\n# ]\n```","ref":"XlsxReader.html#module-example","title":"Example - XlsxReader","type":"module"},{"doc":"Sheets are loaded on-demand by `sheet/3` and `sheets/2`.\n\nThe sheet contents is returned as a list of lists:\n\n```elixir\n[\n  [\"A1\", \"B1\", \"C1\" | _],\n  [\"A2\", \"B2\", \"C2\" | _],\n  [\"A3\", \"B3\", \"C3\" | _],\n  | _\n]\n```\n\nThe behavior of the sheet parser can be customized for each\nindividual sheet, see `sheet/3`.","ref":"XlsxReader.html#module-sheet-contents","title":"Sheet contents - XlsxReader","type":"module"},{"doc":"This library takes a best effort approach for determining cell types.\nIn order of priority, the actual type of an XLSX cell value is determined using:\n\n1. basic cell properties (e.g. boolean)\n2. predefined known styles (e.g. default money/date formats)\n3. introspection of the [custom format string](https://support.microsoft.com/en-us/office/number-format-codes-5026bbd6-04bc-48cd-bf33-80f18b4eae68) associated with the cell","ref":"XlsxReader.html#module-cell-types","title":"Cell types - XlsxReader","type":"module"},{"doc":"* percentages\n* ISO 8601 date/time (y-m-d)\n* US date/time (m/d/y)\n* European date/time (d/m/y)","ref":"XlsxReader.html#module-custom-formats-supported-by-default","title":"Custom formats supported by default - XlsxReader","type":"module"},{"doc":"If the spreadsheet you need to process contains some unusual cell formatting, you\nmay provide hints to map format strings to a known cell type.\n\nThe hints are given as a list of `{matcher, type}` tuples. The matcher is either a\nstring or regex to match against the custom format string. The supported types are:\n\n* `:string`\n* `:number`\n* `:percentage`\n* `:date`\n* `:time`\n* `:date_time`\n* `:unsupported` (used for explicitly unsupported styles and formats)","ref":"XlsxReader.html#module-additional-custom-formats-support","title":"Additional custom formats support - XlsxReader","type":"module"},{"doc":"Cell data which could not be converted using the detected format is returned as the `\"#ERROR\"` placeholder.\n\n#### Example\n\n```elixir\n[\n  {\"mmm yy\", :date},\n  {~r/mmm? yy hh:mm/, :date_time},\n  {\"[$CHF]0.00\", :number}\n]\n```\n\nTo find out what custom formats are in use in the workbook, you can inspect `package.workbook.custom_formats`:\n\n```elixir\n# num_fmt_id => format string\n%{\n  \"0\" => \"General\",\n  \"59\" => \"dd/mm/yyyy\",\n  \"60\" => \"dd/mm/yyyy hh:mm\",\n  \"61\" => \"hh:mm\",\n  \"62\" => \"0.0%\",\n  \"63\" => \"[$CHF]0.00\"\n}\n```","ref":"XlsxReader.html#module-conversion-errors","title":"Conversion errors - XlsxReader","type":"module"},{"doc":"Loads all the sheets in the workbook concurrently.\n\nOn success, returns `{:ok, [{sheet_name, rows}, ...]}`.\n\nWhen processing files with multiple sheets, `async_sheets/3` is ~3x faster than `sheets/2`\nbut it comes with a caveat. `async_sheets/3` uses `Task.async_stream/3` under the hood and thus\nruns each concurrent task with a timeout. If you expect your dataset to be of a significant size,\nyou may want to increase it from the default 10000ms (see \"Concurrency options\" below).\n\nIf the order in which the sheets are returned is not relevant for your application, you can\npass `ordered: false` (see \"Concurrency options\" below) for a modest speed gain.","ref":"XlsxReader.html#async_sheets/3","title":"XlsxReader.async_sheets/3","type":"function"},{"doc":"See `sheets/2`.","ref":"XlsxReader.html#async_sheets/3-filtering-options","title":"Filtering options - XlsxReader.async_sheets/3","type":"function"},{"doc":"See `sheet/2`.","ref":"XlsxReader.html#async_sheets/3-sheet-options","title":"Sheet options - XlsxReader.async_sheets/3","type":"function"},{"doc":"* `max_concurrency` - maximum number of tasks to run at the same time (default: `System.schedulers_online/0`)\n  * `ordered` - maintain order consistent with `sheet_names/1` (default: `true`)\n  * `timeout` - maximum duration in milliseconds to process a sheet (default: `10_000`)","ref":"XlsxReader.html#async_sheets/3-concurrency-options","title":"Concurrency options - XlsxReader.async_sheets/3","type":"function"},{"doc":"Opens an XLSX file located on the file system (default) or from memory.","ref":"XlsxReader.html#open/2","title":"XlsxReader.open/2","type":"function"},{"doc":"","ref":"XlsxReader.html#open/2-examples","title":"Examples - XlsxReader.open/2","type":"function"},{"doc":"```elixir\n{:ok, package} = XlsxReader.open(\"test.xlsx\")\n```","ref":"XlsxReader.html#open/2-opening-xlsx-file-on-the-file-system","title":"Opening XLSX file on the file system - XlsxReader.open/2","type":"function"},{"doc":"```elixir\nblob = File.read!(\"test.xlsx\")\n\n{:ok, package} = XlsxReader.open(blob, source: :binary)\n```","ref":"XlsxReader.html#open/2-opening-xlsx-file-from-memory","title":"Opening XLSX file from memory - XlsxReader.open/2","type":"function"},{"doc":"* `source`: `:path` (on the file system, default) or `:binary` (in memory)\n  * `supported_custom_formats`: a list of `{regex | string, type}` tuples (see \"Additional custom formats support\")\n  * `exclude_hidden_sheets?`: Whether to exclude hidden sheets in the workbook","ref":"XlsxReader.html#open/2-options","title":"Options - XlsxReader.open/2","type":"function"},{"doc":"Loads the sheet with the given name (see `sheet_names/1`)","ref":"XlsxReader.html#sheet/3","title":"XlsxReader.sheet/3","type":"function"},{"doc":"* `type_conversion` - boolean (default: `true`)\n  * `blank_value` - placeholder value for empty cells (default: `\"\"`)\n  * `empty_rows` - include empty rows (default: `true`)\n  * `number_type` - type used for numeric conversion :`Integer`, `Decimal` or `Float` (default: `Float`)\n  * `skip_row?`: function callback that determines if a row should be skipped.\n     Takes precedence over `blank_value` and `empty_rows`.\n     Defaults to `nil` (keeping the behaviour of `blank_value` and `empty_rows`).\n  * `cell_data_format`: Controls the format of the cell data. Can be `:value` (default, returns the cell value only) or `:cell` (returns instances of `XlsxReader.Cell`).\n\nThe `Decimal` type requires the [decimal](https://github.com/ericmj/decimal) library.","ref":"XlsxReader.html#sheet/3-options","title":"Options - XlsxReader.sheet/3","type":"function"},{"doc":"","ref":"XlsxReader.html#sheet/3-examples","title":"Examples - XlsxReader.sheet/3","type":"function"},{"doc":"When using the `skip_row?` callback, rows are ignored in the parser which is more memory efficient.\n\n```elixir\n# Skip all rows for which all the values are either blank or \"-\"\nXlsxReader.sheet(package, \"Sheet1\", skip_row?: fn row ->\n  Enum.all?(row, & String.trim(&1) in [\"\", \"-\"])\nend)\n\n# Skip all rows for which the first column contains the text \"disabled\"\nXlsxReader.sheet(package, \"Sheet1\", skip_row?: fn [column | _] ->\n  column == \"disabled\"\nend)\n```","ref":"XlsxReader.html#sheet/3-skipping-rows","title":"Skipping rows - XlsxReader.sheet/3","type":"function"},{"doc":"","ref":"XlsxReader.html#sheet_filter_option/2","title":"XlsxReader.sheet_filter_option/2","type":"function"},{"doc":"Lists the names of the sheets in the package's workbook","ref":"XlsxReader.html#sheet_names/1","title":"XlsxReader.sheet_names/1","type":"function"},{"doc":"Loads all the sheets in the workbook.\n\nOn success, returns `{:ok, [{sheet_name, rows}, ...]}`.","ref":"XlsxReader.html#sheets/2","title":"XlsxReader.sheets/2","type":"function"},{"doc":"* `only` - include the sheets whose name matches the filter\n  * `except` - exclude the sheets whose name matches the filter\n\nSheets can filtered by name using:\n\n  * a string (e.g. `\"Exact Match\"`)\n  * a regex (e.g. `~r/Sheet +/`)\n  * a list of string and/or regexes (e.g. `[\"Parameters\", ~r/Sheet [12]/]`)","ref":"XlsxReader.html#sheets/2-filtering-options","title":"Filtering options - XlsxReader.sheets/2","type":"function"},{"doc":"See `sheet/2`.","ref":"XlsxReader.html#sheets/2-sheet-options","title":"Sheet options - XlsxReader.sheets/2","type":"function"},{"doc":"Error tuple with message describing the cause of the error","ref":"XlsxReader.html#t:error/0","title":"XlsxReader.error/0","type":"type"},{"doc":"Option to specify the XLSX file source","ref":"XlsxReader.html#t:open_option/0","title":"XlsxReader.open_option/0","type":"type"},{"doc":"List of cell values","ref":"XlsxReader.html#t:row/0","title":"XlsxReader.row/0","type":"type"},{"doc":"List of rows","ref":"XlsxReader.html#t:rows/0","title":"XlsxReader.rows/0","type":"type"},{"doc":"Sheet name","ref":"XlsxReader.html#t:sheet_name/0","title":"XlsxReader.sheet_name/0","type":"type"},{"doc":"Source for the XLSX file: file system (`:path`) or in-memory (`:binary`)","ref":"XlsxReader.html#t:source/0","title":"XlsxReader.source/0","type":"type"},{"doc":"Cell structure.\n\nThis structure contains the information of a cell in a sheet.\n\n- `value` - The value of the cell\n- `formula` - The formula used in the cell, if any\n- `ref` - The cell reference, like 'A1', 'B2', etc.\n\nThis structure is used when the `cell_data_format` option is set to `:cell`.","ref":"XlsxReader.Cell.html","title":"XlsxReader.Cell","type":"module"},{"doc":"XLSX cell data","ref":"XlsxReader.Cell.html#t:t/0","title":"XlsxReader.Cell.t/0","type":"type"},{"doc":"Conversion of cell values to Elixir types.","ref":"XlsxReader.Conversion.html","title":"XlsxReader.Conversion","type":"module"},{"doc":"Returns the base date for the given date system.","ref":"XlsxReader.Conversion.html#base_date/1","title":"XlsxReader.Conversion.base_date/1","type":"function"},{"doc":"iex> XlsxReader.Conversion.base_date(1900)\n    ~D[1899-12-30]\n\n    iex> XlsxReader.Conversion.base_date(1904)\n    ~D[1904-01-01]\n\n    iex> XlsxReader.Conversion.base_date(2019)\n    :error","ref":"XlsxReader.Conversion.html#base_date/1-examples","title":"Examples - XlsxReader.Conversion.base_date/1","type":"function"},{"doc":"Converts the string representation of a truth value into to a boolean.\n\nCells with type attribute `\"b\"` store boolean values as a single digit: `\"1\"` or `\"0\"`.","ref":"XlsxReader.Conversion.html#to_boolean/1","title":"XlsxReader.Conversion.to_boolean/1","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_boolean(\"1\")\n    {:ok, true}\n\n    iex> XlsxReader.Conversion.to_boolean(\"0\")\n    {:ok, false}\n\n    iex> XlsxReader.Conversion.to_boolean(\"true\")\n    :error","ref":"XlsxReader.Conversion.html#to_boolean/1-examples","title":"Examples - XlsxReader.Conversion.to_boolean/1","type":"function"},{"doc":"Converts a serial date into a `Date`.","ref":"XlsxReader.Conversion.html#to_date/2","title":"XlsxReader.Conversion.to_date/2","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_date(\"40396\")\n    {:ok, ~D[2010-08-06]}\n\n    iex> XlsxReader.Conversion.to_date(\"43783\")\n    {:ok, ~D[2019-11-14]}\n\n    iex> XlsxReader.Conversion.to_date(\"1\", ~D[1999-12-31])\n    {:ok, ~D[2000-01-01]}\n\n    iex> XlsxReader.Conversion.to_date(\"-1\", ~D[1999-12-31])\n    :error","ref":"XlsxReader.Conversion.html#to_date/2-examples","title":"Examples - XlsxReader.Conversion.to_date/2","type":"function"},{"doc":"Converts a serial date to a `NaiveDateTime`.","ref":"XlsxReader.Conversion.html#to_date_time/2","title":"XlsxReader.Conversion.to_date_time/2","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_date_time(\"43783.0\")\n    {:ok, ~N[2019-11-14 00:00:00]}\n\n    iex> XlsxReader.Conversion.to_date_time(\"43783.760243055556\")\n    {:ok, ~N[2019-11-14 18:14:45]}\n\n    iex> XlsxReader.Conversion.to_date_time(\"0.4895833333333333\")\n    {:ok, ~N[1899-12-30 11:45:00]}\n\n    iex> XlsxReader.Conversion.to_date_time(\"1.760243055556\", ~D[1999-12-31])\n    {:ok, ~N[2000-01-01 18:14:45]}\n\n    iex> XlsxReader.Conversion.to_date_time(\"-30.760243055556\", ~D[1999-12-31])\n    :error","ref":"XlsxReader.Conversion.html#to_date_time/2-examples","title":"Examples - XlsxReader.Conversion.to_date_time/2","type":"function"},{"doc":"Converts a string into an arbitrary precision [decimal](https://github.com/ericmj/decimal).","ref":"XlsxReader.Conversion.html#to_decimal/1","title":"XlsxReader.Conversion.to_decimal/1","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_decimal(\"123\")\n    {:ok, %Decimal{coef: 123, exp: 0, sign: 1}}\n\n    iex> XlsxReader.Conversion.to_decimal(\"-123.45\")\n    {:ok, %Decimal{coef: 12345, exp: -2, sign: -1}}\n\n    iex> XlsxReader.Conversion.to_decimal(\"0.12345e3\")\n    {:ok, %Decimal{coef: 12345, exp: -2, sign: 1}}\n\n    iex> XlsxReader.Conversion.to_decimal(\"0.12345E3\")\n    {:ok, %Decimal{coef: 12345, exp: -2, sign: 1}}\n\n    iex> XlsxReader.Conversion.to_decimal(\"bogus\")\n    :error","ref":"XlsxReader.Conversion.html#to_decimal/1-examples","title":"Examples - XlsxReader.Conversion.to_decimal/1","type":"function"},{"doc":"Converts a string into a float.","ref":"XlsxReader.Conversion.html#to_float/1","title":"XlsxReader.Conversion.to_float/1","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_float(\"123\")\n    {:ok, 123.0}\n\n    iex> XlsxReader.Conversion.to_float(\"-123.45\")\n    {:ok, -123.45}\n\n    iex> XlsxReader.Conversion.to_float(\"0.12345e3\")\n    {:ok, 123.45}\n\n    iex> XlsxReader.Conversion.to_float(\"0.12345E3\")\n    {:ok, 123.45}\n\n    iex> XlsxReader.Conversion.to_float(\"bogus\")\n    :error","ref":"XlsxReader.Conversion.html#to_float/1-examples","title":"Examples - XlsxReader.Conversion.to_float/1","type":"function"},{"doc":"Converts a string into an integer.","ref":"XlsxReader.Conversion.html#to_integer/1","title":"XlsxReader.Conversion.to_integer/1","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_integer(\"123\")\n    {:ok, 123}\n\n    iex> XlsxReader.Conversion.to_integer(\"-123\")\n    {:ok, -123}\n\n    iex> XlsxReader.Conversion.to_integer(\"123.45\")\n    :error\n\n    iex> XlsxReader.Conversion.to_integer(\"bogus\")\n    :error","ref":"XlsxReader.Conversion.html#to_integer/1-examples","title":"Examples - XlsxReader.Conversion.to_integer/1","type":"function"},{"doc":"Converts a string into the given number type.\n\nSupported number types are: `Integer`, `Float`, `String` or `Decimal` (requires the [decimal](https://github.com/ericmj/decimal) library)","ref":"XlsxReader.Conversion.html#to_number/2","title":"XlsxReader.Conversion.to_number/2","type":"function"},{"doc":"iex> XlsxReader.Conversion.to_number(\"123\", Integer)\n    {:ok, 123}\n\n    iex> XlsxReader.Conversion.to_number(\"-123.45\", Float)\n    {:ok, -123.45}\n\n    iex> XlsxReader.Conversion.to_number(\"0.12345e3\", Float)\n    {:ok, 123.45}\n\n    iex> XlsxReader.Conversion.to_number(\"-123.45\", Decimal)\n    {:ok, %Decimal{coef: 12345, exp: -2, sign: -1}}\n\n    iex> XlsxReader.Conversion.to_number(\"0.12345E3\", Decimal)\n    {:ok, %Decimal{coef: 12345, exp: -2, sign: 1}}\n\n    iex> XlsxReader.Conversion.to_number(\"-123.45\", String)\n    {:ok, \"-123.45\"}\n\n    iex> XlsxReader.Conversion.to_number(\"0.12345e3\", String)\n    {:ok, \"0.12345e3\"}\n\n    iex> XlsxReader.Conversion.to_number(\"123.0\", Integer)\n    :error","ref":"XlsxReader.Conversion.html#to_number/2-examples","title":"Examples - XlsxReader.Conversion.to_number/2","type":"function"},{"doc":"Date system identified by its reference year","ref":"XlsxReader.Conversion.html#t:date_system/0","title":"XlsxReader.Conversion.date_system/0","type":"type"},{"doc":"Supported number types identified by module name","ref":"XlsxReader.Conversion.html#t:number_type/0","title":"XlsxReader.Conversion.number_type/0","type":"type"},{"doc":"Supported number value types","ref":"XlsxReader.Conversion.html#t:number_value/0","title":"XlsxReader.Conversion.number_value/0","type":"type"},{"doc":"XSLX Package structure.\n\nThis structure is initialized by `XlsxReader.open/2` and is used to access\nthe contents of the file\n\nIt should not be manipulated directly.","ref":"XlsxReader.Package.html","title":"XlsxReader.Package","type":"module"},{"doc":"XLSX package","ref":"XlsxReader.Package.html#t:t/0","title":"XlsxReader.Package.t/0","type":"type"},{"doc":"Worksheet structure.\n\nThis structure only contains the information useful to identify and retrieve the sheet actual data.\n\n- `name` - name of the sheet\n- `rid` - relationship ID used to retrieve the corresponding sheet in the archive\n- `sheet_id` - unique identifier of the sheet withing the workbook (unused by XlsxReader)\n\nTo access the sheet cells, see `XlsxReader.sheet/3` and `XlsxReader.sheets/2`.","ref":"XlsxReader.Sheet.html","title":"XlsxReader.Sheet","type":"module"},{"doc":"XLSX worksheet metadata","ref":"XlsxReader.Sheet.html#t:t/0","title":"XlsxReader.Sheet.t/0","type":"type"},{"doc":"Utility functions and types to deal with cell styles","ref":"XlsxReader.Styles.html","title":"XlsxReader.Styles","type":"module"},{"doc":"Guesses the type of a cell based on its style.\n\nThe type is:\n\n1. looked-up from a list of \"standard\" styles, or\n2. guessed from a list of default supported custom formats, or\n3. guessed from a list of user-provided supported custom formats.\n\nIf no type could be guessed, returns `nil`.","ref":"XlsxReader.Styles.html#get_style_type/3","title":"XlsxReader.Styles.get_style_type/3","type":"function"},{"doc":"Matches the text representation of a cell value","ref":"XlsxReader.Styles.html#t:custom_format_matcher/0","title":"XlsxReader.Styles.custom_format_matcher/0","type":"type"},{"doc":"","ref":"XlsxReader.Styles.html#t:custom_formats/0","title":"XlsxReader.Styles.custom_formats/0","type":"type"},{"doc":"Knwon cell styles for which type conversion is supported","ref":"XlsxReader.Styles.html#t:known_style_type/0","title":"XlsxReader.Styles.known_style_type/0","type":"type"},{"doc":"Cell styles for which type conversion is supported","ref":"XlsxReader.Styles.html#t:style_type/0","title":"XlsxReader.Styles.style_type/0","type":"type"},{"doc":"","ref":"XlsxReader.Styles.html#t:style_types/0","title":"XlsxReader.Styles.style_types/0","type":"type"},{"doc":"","ref":"XlsxReader.Styles.html#t:supported_custom_formats/0","title":"XlsxReader.Styles.supported_custom_formats/0","type":"type"},{"doc":"Workbook structure.\n\n- `sheets` - list of sheet metadata\n- `rels` - workbook relationships\n- `shared_strings` - list of shared strings\n- `style_types` - List of types indexed by style\n- `custom_formats` - Map of custom formats declared for this document\n- `base_date` - base date for all serial dates in the workbook\n- `options` - Map of options for the workbook. Currently includes:\n  - `exclude_hidden_sheets?`: Whether to exclude hidden sheets in the workbook","ref":"XlsxReader.Workbook.html","title":"XlsxReader.Workbook","type":"module"},{"doc":"XLSX workbook","ref":"XlsxReader.Workbook.html#t:t/0","title":"XlsxReader.Workbook.t/0","type":"type"},{"doc":"![XlsxReader logo](https://raw.githubusercontent.com/xavier/xlsx_reader/master/assets/logo.png)\n\n# XlsxReader\n\n![Build status](https://github.com/xavier/xlsx_reader/workflows/CI/badge.svg)\n\nAn XLSX reader in Elixir.\n\nFeatures:\n\n- Accepts XLSX data located on the file system or in memory\n- Automatic type conversions (numbers, date & times, booleans)\n- Optional support for arbitrary precision [decimal](https://github.com/ericmj/decimal) numbers\n- Straightforward architecture: no ETS tables, no race-conditions, no manual resource management\n\nThe docs can be found at [https://hexdocs.pm/xlsx_reader](https://hexdocs.pm/xlsx_reader).","ref":"readme.html","title":"README","type":"extras"},{"doc":"Add `xlsx_reader` as a dependency in your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:xlsx_reader, \"~> 0.8.0\"}\n  ]\nend\n```\n\nRun `mix deps.get` in your shell to fetch and compile XlsxReader.","ref":"readme.html#installation","title":"Installation - README","type":"extras"},{"doc":"","ref":"readme.html#examples","title":"Examples - README","type":"extras"},{"doc":"```elixir\n\n{:ok, package} = XlsxReader.open(\"test.xlsx\")\n\nXlsxReader.sheet_names(package)\n# [\"Sheet 1\", \"Sheet 2\", \"Sheet 3\"]\n\n{:ok, rows} = XlsxReader.sheet(package, \"Sheet 1\")\n# [\n#   [\"Date\", \"Temperature\"],\n#   [~D[2019-11-01], 8.4],\n#   [~D[2019-11-02], 7.5],\n#   ...\n# ]\n```","ref":"readme.html#loading-from-the-file-system","title":"Loading from the file system - README","type":"extras"},{"doc":"```elixir\nblob = File.read!(\"test.xlsx\")\n\n{:ok, package} = XlsxReader.open(blob, source: :binary)\n```","ref":"readme.html#loading-from-memory","title":"Loading from memory - README","type":"extras"},{"doc":"```elixir\n{:ok, sheets} = XlsxReader.sheets(package)\n# [\n#   {\"Sheet 1\", [[\"Date\", \"Temperature\"], ...]},\n#   {\"Sheet 2\", [...]},\n#   ...\n# ]\n```","ref":"readme.html#loading-all-sheets-at-once","title":"Loading all sheets at once - README","type":"extras"},{"doc":"```elixir\n{:ok, sheets} = XlsxReader.sheets(package, only: [\"Parameters\", ~r/Sheet \\d+/], except: [\"Sheet 2\"])\n# [\n#   {\"Parameters\", [...]},\n#   {\"Sheet 1\", [...]},\n#   {\"Sheet 3\", [...]},\n#   {\"Sheet 4\", [...]},\n#   ...\n# ]\n```","ref":"readme.html#loading-sheets-selectively","title":"Loading sheets selectively - README","type":"extras"},{"doc":"```elixir\n{:ok, sheets} = XlsxReader.async_sheets(package)\n# [\n#   {\"Sheet 1\", [[\"Date\", \"Temperature\"], ...]},\n#   {\"Sheet 2\", [...]},\n#   ...\n# ]\n```","ref":"readme.html#loading-all-sheets-at-once-concurrently","title":"Loading all sheets at once concurrently - README","type":"extras"},{"doc":"```elixir\n{:ok, rows} = XlsxReader.sheet(package, \"Sheet 1\", number_type: Decimal)\n# [\n#   [\"Date\", \"Temperature\"],\n#   [~D[2019-11-01], %Decimal{coef: 84, exp: -1, sign: 1}],\n#   [~D[2019-11-02], %Decimal{coef: 75, exp: -1, sign: 1}],\n#   ...\n# ]\n```","ref":"readme.html#using-arbitrary-precision-numbers","title":"Using arbitrary precision numbers - README","type":"extras"},{"doc":"```elixir\n{:ok, rows} = XlsxReader.sheet(package, \"Sheet 1\", cell_data_format: :cell)\n# [\n#   [%Cell{value: 1234.0, formula: \"SUM(B1, B10)\", ref: \"A1\"}, ...],\n#   ...\n# ]\n```","ref":"readme.html#access-cell-formulas","title":"Access cell formulas - README","type":"extras"},{"doc":"","ref":"readme.html#development","title":"Development - README","type":"extras"},{"doc":"1. `mix run benchmark/init.exs` to create the benchmarking dataset\n2. `mix run benchmark/run.exs` to run the [Benchee](https://github.com/bencheeorg/benchee) suite","ref":"readme.html#benchmarking","title":"Benchmarking - README","type":"extras"},{"doc":"In order of appearance:\n\n- Xavier Defrang ([xavier](https://github.com/xavier))\n- Darragh Enright ([darraghenright](https://github.com/darraghenright))\n- Patryk Woziński ([patrykwozinski](https://github.com/patrykwozinski))\n- Evaldo Bratti ([evaldobratti](https://github.com/evaldobratti))\n- Zach Liss ([ZachLiss](https://github.com/ZachLiss))\n- [Paranojik](https://github.com/paranojik)\n- Juan Barrios ([03juan](https://github.com/03juan))\n- Dylan Harness ([dharness](https://github.com/dharness))\n- Victor Rodrigues ([rodrigues](https://github.com/rodrigues))\n- Jose Valim ([josevalim](https://github.com/josevalim))\n- Vinicius Moraes ([ding-an-sich](https://github.com/ding-an-sich))","ref":"readme.html#contributors","title":"Contributors - README","type":"extras"},{"doc":"Copyright 2020 Xavier Defrang\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license","title":"License - README","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}